<?php
/**
 * @file
 * Theme functions for user generated content module.
 */

/**
 * Theme loading message for UGC project.
 *
 * @param array $parameters
 *   An array of parameters for this function:
 *     string 'message'
 *       Message to display to user.
 *     boolean 'error'
 *       Is error.
 */
function theme_ugc_loading_message($parameters) {
  return t('LOAD ERROR');
}

/**
 * Theme summary of UGC project.
 *
 * @param array $element
 *   Contains the 'element' parameter:
 *     array 'element'
 *       Node object for UGC project record.
 */
function theme_ugc_project_summary($element) {
  // Output the block's title.
  $project = $element['element'];
  $html = '<h2>' . $project->title . '</h2>';
  // See if there's body content for this block.
  $lang = LANGUAGE_NONE;
  if (!empty($project->body)
   && array_key_exists($lang, $project->body)
   && array_key_exists(0, $project->body[$lang])) {
    $html .= '<div>' . $project->body[$lang][0]['safe_value'] . '</div>';
  }
  return $html;
}

/**
 * Theme UGC project closed message.
 *
 * @param array $element
 *   ['element'] - Node object for UGC project record.
 */
function theme_ugc_project_closed($project) {
  return t('CLOSED');
}

/**
 * Theme user access denied to create UGC content message.
 *
 * @param array $parameters
 *   An array of parameters for this function:
 *     object 'project'
 *       Node object for UGC project record.
 *     object 'user'
 *       Logged in user record.
 */
function theme_ugc_access_denied($parameters) {
  return t('NO ACCESS');
}

/**
 * Theme user not logged in message.
 *
 * @param array $parameters
 *   An array of parameters for this function:
 *     object 'project'
 *       Node object for UGC project record.
 */
function theme_ugc_user_not_logged_in($project) {
  return t('NOT LOGGED IN');
}

/**
 * Theme UGC form output.
 *
 * @param array $parameters
 *   An array of parameters for this function:
 *     string 'form'
 *       HTML for form element.
 *     string 'node_type'
 *       Node type defining form.
 */
function theme_ugc_form($parameters) {
  return drupal_render($parameters['output']);
}

/**
 * Theme a UGC field that is allowed multiple values.
 *
 * @param array $parameters
 *   Contains the 'element' parameter:
 *     array 'element'
 *       Multi-value field definition.
 */
function theme_ugc_multi_field($parameters) {
  $language = LANGUAGE_NONE;
  $html = '';
  // Grab the form element.
  if (empty($parameters['element'])) {
    return '';
  }
  $element = $parameters['element'];
  // Construct a fieldset HTML element.
  $id = !empty($element['#id']) ? $element['#id'] : '';
  $class = !empty($element['#attributes']['class']) ? implode($element['#attributes']['class'], ' ') : '';
  $html .= '<fieldset id="' . $id . '" class="' . $class . '">';
  // Add defined prefix.
  if (!empty($element['#prefix'])) {
    $html .= $element['#prefix'];
  }
  // Add field title.
  if (!empty($element['#title'])) {
    $html .= '<legend>';
    $html .= '<span class="fieldset-legend">' . $element['#title'] . '</span>';
    if (!empty($element['#required_flag']) && $element['#required_flag']) {
      $html .= ' <span class="form-required" title="' . t('This field is required.') . '">*</span>';
    }
    $html .= '</legend>';
  }
  // Add a fieldset wrapper div.
  $html .= '<div class="fieldset-wrapper">';
  // Add field description.
  if (!empty($element['#description'])) {
    $html .= '<div class="fieldset-description">' . $element['#description'] . '</div>';
  }
  // Get a list of this element's children.
  $children = element_children($element[$language]);
  // Remove each child element's title and description - the details we have on
  // the fieldset itself will suffice. Also remove the required flag, so that
  // Drupal doesn't automatically apply a 'required' asterisk to the field. The
  // field is still required though - this is only for presentation.
  foreach ($children as $child_key) {
    $element[$language][$child_key]['#title'] = '';
    $element[$language][$child_key]['#description'] = '';
    $element[$language][$child_key]['#required'] = 0;
  }
  // Render the child form elements of this field.
  $html .= drupal_render_children($element[$language], $children);
  // Add defined suffix.
  if (!empty($element['#suffix'])) {
    $html .= $element['#suffix'];
  }
  // Close the fieldset wrapper div and the fieldset.
  $html .= '</div></fieldset>';
  // Return the rendered HTML.
  return $html;
}
